==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/IdMatrixResults.java <==
package com.example.model;

/**
 * Model for SearchResults
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "IdMatrixResults", description = "Model for SearchResults")
@javax.xml.bind.annotation.XmlRootElement(name = "IdMatrixResults")
public class IdMatrixResults implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String overall = null;
	private java.util.List<com.example.model.RulesResults> rulesResults = null;
	private com.example.model.SearchResults searchResults = null;
	private com.example.model.VerificationOutcome verificationOutcome = null;
	
	/**
	 */
	public IdMatrixResults overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	@javax.validation.constraints.NotNull
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	/**
	 */
	public IdMatrixResults rulesResults(java.util.List<com.example.model.RulesResults> rulesResults) {
		setRulesResults(rulesResults);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("rulesResults")
	@javax.validation.Valid
	public java.util.List<com.example.model.RulesResults> getRulesResults() {
		return this.rulesResults;
	}
	public void setRulesResults(java.util.List<com.example.model.RulesResults> rulesResults) {
		this.rulesResults = rulesResults;
	}
	public IdMatrixResults addRulesResult(com.example.model.RulesResults rulesResult) {
		if (this.rulesResults == null) {
			this.rulesResults = new java.util.ArrayList<com.example.model.RulesResults>();
		}
		this.rulesResults.add(rulesResult);
		return this;
	}
	
	/**
	 * Model for SearchResults
	 */
	public IdMatrixResults searchResults(com.example.model.SearchResults searchResults) {
		setSearchResults(searchResults);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for SearchResults")
	@com.fasterxml.jackson.annotation.JsonProperty("searchResults")
	@javax.validation.Valid
	public com.example.model.SearchResults getSearchResults() {
		return this.searchResults;
	}
	public void setSearchResults(com.example.model.SearchResults searchResults) {
		this.searchResults = searchResults;
	}
	
	/**
	 * Model for VerificationOutcome
	 */
	public IdMatrixResults verificationOutcome(com.example.model.VerificationOutcome verificationOutcome) {
		setVerificationOutcome(verificationOutcome);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for VerificationOutcome")
	@com.fasterxml.jackson.annotation.JsonProperty("verificationOutcome")
	@javax.validation.Valid
	public com.example.model.VerificationOutcome getVerificationOutcome() {
		return this.verificationOutcome;
	}
	public void setVerificationOutcome(com.example.model.VerificationOutcome verificationOutcome) {
		this.verificationOutcome = verificationOutcome;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		IdMatrixResults idMatrixResults = (IdMatrixResults) o;
		return java.util.Objects.equals(this.overall, idMatrixResults.overall)
				&& java.util.Objects.equals(this.rulesResults, idMatrixResults.rulesResults)
				&& java.util.Objects.equals(this.searchResults, idMatrixResults.searchResults)
				&& java.util.Objects.equals(this.verificationOutcome, idMatrixResults.verificationOutcome);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.overall, this.rulesResults, this.searchResults, this.verificationOutcome);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class IdMatrixResults {\n");
		
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("    rulesResults: ").append(toIndentedString(this.rulesResults)).append("\n");
		sb.append("    searchResults: ").append(toIndentedString(this.searchResults)).append("\n");
		sb.append("    verificationOutcome: ").append(toIndentedString(this.verificationOutcome)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/IdMatrixResults.java <==
package com.example.model;

/**
 * Model for SearchResults
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "IdMatrixResults", description = "Model for SearchResults")
@javax.xml.bind.annotation.XmlRootElement(name = "IdMatrixResults")
public class IdMatrixResults implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String overall = null;
	private java.util.List<com.example.model.RulesResults> rulesResults = null;
	private com.example.model.SearchResults searchResults = null;
	private com.example.model.VerificationOutcome verificationOutcome = null;
	
	/**
	 */
	public IdMatrixResults overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "overall")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	@javax.validation.constraints.NotNull
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	/**
	 */
	public IdMatrixResults rulesResults(java.util.List<com.example.model.RulesResults> rulesResults) {
		setRulesResults(rulesResults);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "rulesResults")
	@com.fasterxml.jackson.annotation.JsonProperty("rulesResults")
	@javax.validation.Valid
	public java.util.List<com.example.model.RulesResults> getRulesResults() {
		return this.rulesResults;
	}
	public void setRulesResults(java.util.List<com.example.model.RulesResults> rulesResults) {
		this.rulesResults = rulesResults;
	}
	public IdMatrixResults addRulesResult(com.example.model.RulesResults rulesResult) {
		if (this.rulesResults == null) {
			this.rulesResults = new java.util.ArrayList<com.example.model.RulesResults>();
		}
		this.rulesResults.add(rulesResult);
		return this;
	}
	
	/**
	 * Model for SearchResults
	 */
	public IdMatrixResults searchResults(com.example.model.SearchResults searchResults) {
		setSearchResults(searchResults);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "searchResults", description = "Model for SearchResults")
	@com.fasterxml.jackson.annotation.JsonProperty("searchResults")
	@javax.validation.Valid
	public com.example.model.SearchResults getSearchResults() {
		return this.searchResults;
	}
	public void setSearchResults(com.example.model.SearchResults searchResults) {
		this.searchResults = searchResults;
	}
	
	/**
	 * Model for VerificationOutcome
	 */
	public IdMatrixResults verificationOutcome(com.example.model.VerificationOutcome verificationOutcome) {
		setVerificationOutcome(verificationOutcome);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "verificationOutcome", description = "Model for VerificationOutcome")
	@com.fasterxml.jackson.annotation.JsonProperty("verificationOutcome")
	@javax.validation.Valid
	public com.example.model.VerificationOutcome getVerificationOutcome() {
		return this.verificationOutcome;
	}
	public void setVerificationOutcome(com.example.model.VerificationOutcome verificationOutcome) {
		this.verificationOutcome = verificationOutcome;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		IdMatrixResults idMatrixResults = (IdMatrixResults) o;
		return java.util.Objects.equals(this.overall, idMatrixResults.overall)
				&& java.util.Objects.equals(this.rulesResults, idMatrixResults.rulesResults)
				&& java.util.Objects.equals(this.searchResults, idMatrixResults.searchResults)
				&& java.util.Objects.equals(this.verificationOutcome, idMatrixResults.verificationOutcome);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.overall, this.rulesResults, this.searchResults, this.verificationOutcome);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class IdMatrixResults {\n");
		
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("    rulesResults: ").append(toIndentedString(this.rulesResults)).append("\n");
		sb.append("    searchResults: ").append(toIndentedString(this.searchResults)).append("\n");
		sb.append("    verificationOutcome: ").append(toIndentedString(this.verificationOutcome)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
